@@ -15,7 +15,7 @@
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL NCD.
  * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
- * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
+ * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
  * Author:  Keith Packard, Network Computing Devices
@@ -33,7 +33,7 @@
 
 static XExtensionInfo _lbx_info_data;
 static XExtensionInfo *lbx_info = &_lbx_info_data;
-static /* const */ char *lbx_extension_name = LBXNAME;
+static const char *lbx_extension_name = LBXNAME;
 
 #define LbxCheckExtension(dpy,i,val) \
   XextCheckExtension (dpy, i, lbx_extension_name, val)
@@ -55,11 +55,11 @@ static /* const */ XExtensionHooks lbx_extension_hooks = {
     error_string,			/* error_string */
 };
 
-static /* const */ char *lbx_error_list[] = {
+static const char *lbx_error_list[] = {
     "BadLbxClient",			/* BadLbxClient */
 };
 
-static XEXT_GENERATE_FIND_DISPLAY (find_display, lbx_info, lbx_extension_name, 
+static XEXT_GENERATE_FIND_DISPLAY (find_display, lbx_info, lbx_extension_name,
 				   &lbx_extension_hooks, LbxNumberEvents, NULL)
 
 static XEXT_GENERATE_CLOSE_DISPLAY (close_display, lbx_info)
